==> helm-annotations-2.10.0-sources.jar: io/dekorate/helm/config/ValueReference.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class ValueReference{
  public ValueReference() {
  }
  public ValueReference(String property,java.lang.String[] paths,java.lang.String profile,java.lang.String value) {
    this.property = property;
    this.paths = paths != null ? paths : new java.lang.String[0];
    this.profile = profile;
    this.value = value;
  }
  private java.lang.String property;
  private java.lang.String[] paths;
  private java.lang.String profile;
  private java.lang.String value;
  public java.lang.String getProperty() {
    return this.property;
  }
  
  /**
   * The path expressions where to map the property.
   */
public java.lang.String[] getPaths() {
    return this.paths;
  }
  public java.lang.String getProfile() {
    return this.profile;
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public static ValueReferenceBuilder newBuilder() {
    return new ValueReferenceBuilder();
  }
  public static io.dekorate.helm.config.ValueReferenceBuilder newBuilderFromDefaults() {
    return new io.dekorate.helm.config.ValueReferenceBuilder();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValueReference that = (ValueReference) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  paths,  profile,  value,  super.hashCode());
  }
  
}

==> helm-annotations-2.11.3-sources.jar: io/dekorate/helm/config/ValueReference.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class ValueReference{
  public ValueReference() {
  }
  public ValueReference(String property,java.lang.String[] paths,java.lang.String profile,java.lang.String value,java.lang.String expression) {
    this.property = property;
    this.paths = paths != null ? paths : new java.lang.String[0];
    this.profile = profile;
    this.value = value;
    this.expression = expression;
  }
  private java.lang.String property;
  private java.lang.String[] paths;
  private java.lang.String profile;
  private java.lang.String value;
  private java.lang.String expression;
  public java.lang.String getProperty() {
    return this.property;
  }
  
  /**
   * The path expressions where to map the property.
   */
public java.lang.String[] getPaths() {
    return this.paths;
  }
  public java.lang.String getProfile() {
    return this.profile;
  }
  public java.lang.String getValue() {
    return this.value;
  }
  
  /**
   * If not provided, it will use `{{ .Values.<root alias>.<property> }}`.
   * @return The complete Helm expression to be replaced with.
   */
public java.lang.String getExpression() {
    return this.expression;
  }
  public static ValueReferenceBuilder newBuilder() {
    return new ValueReferenceBuilder();
  }
  public static io.dekorate.helm.config.ValueReferenceBuilder newBuilderFromDefaults() {
    return new io.dekorate.helm.config.ValueReferenceBuilder();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValueReference that = (ValueReference) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    if (expression != null ? !expression.equals(that.expression) :that.expression != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  paths,  profile,  value,  expression,  super.hashCode());
  }
  
}
